<?php

namespace Ems\Controllers;

use Exception\Messages;
use Service\LogService;
use Service\OAuth\OAuthCustomImpl;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\HTTP\Kernel;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;


use Ems\Services\EquipeService;

class EquipeController {
    protected $equipeService;

    public function __construct(EquipeService $equipeService) {
        $this->equipeService = $equipeService;
    }

    public function getMonitoramentoEquipeBancoHoras(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura   = (int) $row['NRESTRUTURAM'];
            $nrPeriodo     = (int) $row['NRPERIODOAPURACAO'];

            $saldoBancoDeHoras = $this->equipeService->
                getMonitoramentoEquipeBancoHoras($nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeBancoHoras', $saldoBancoDeHoras));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeAtrasos(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $atrasos = $this->equipeService->
                getMonitoramentoEquipeAtrasos($nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeAtrasos', $atrasos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeFaltas(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $faltas = $this->equipeService->
                getMonitoramentoEquipeFaltas($nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeFaltas', $faltas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeHorasExtras(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $horasExtras = $this->equipeService->
                getMonitoramentoEquipeHorasExtras($nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeHorasExtras', $horasExtras));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeAtestados(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $atestados = $this->equipeService->
                getMonitoramentoEquipeAtestados($nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeAtestados', $atestados));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeFerias(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $ferias = $this->equipeService->
                getMonitoramentoEquipeFerias($nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeFerias', $ferias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeContrato(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];

            $contratos = $this->equipeService->getMonitoramentoEquipeContrato($nrEstrutura);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeContrato', $contratos));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeLicenca(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];

            $licencas = $this->equipeService->getMonitoramentoEquipeLicenca($nrEstrutura);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeLicenca', $licencas));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
    public function getMonitoramentoEquipeAfastamentos(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $afastamentos = $this->equipeService->getMonitoramentoEquipeAfastamentos($row);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeAfastamentos', $afastamentos));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
    public function getMonitoramentoEquipeUltimasFerias(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $ultFerias = $this->equipeService->
                getMonitoramentoEquipeUltimasFerias($nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeUltimasFerias', $ultFerias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoAusenciaMarcacaoPrevista(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $ausencias = $this->equipeService->
            getMonitoramentoAusenciaMarcacaoPrevista($nrEstrutura, $nrPeriodo);

            $response->addDataSet(new DataSet('getMonitoramentoAusenciaMarcacaoPrevista', $ausencias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getMonitoramentoEquipeAdcNoturno(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEstrutura = (int) $row['NRESTRUTURAM'];
            $nrPeriodo   = (int) $row['NRPERIODOAPURACAO'];

            $adcNoturno = $this->equipeService->
                getMonitoramentoEquipeAdcNoturno($nrEstrutura, $nrPeriodo, null);

            $response->addDataSet(new DataSet('getMonitoramentoEquipeAdcNoturno', $adcNoturno));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
