<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;
use Ems\Util\Utils;

class IndicadoresSegurancaTrabalhoRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->connection = $entityManager->getConnection();
    }

    public function getTotalAcidentesDashboard(
        $row
   ) {
       $sql = <<<SQL
       SELECT COUNT(*) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
SQL;

   $query = $this->connection->prepare($sql);
   $query->execute(
       array(
           'P_NRORG'       => (int) $row['NRORG'],
           'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
           'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
           'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
           'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
           'P_NRESTRUTSIND' => null,
           'P_NRESTRUTTOMAD' => null,
           'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
       )
   );

   return $query->fetchAll();
   }

    public function getTotalAcidentes(
         $row
    ) {

        $sql = <<<SQL
        SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH AS INDICADOR , COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

    $query = $this->connection->prepare($sql);
    $query->execute(
        array(
            'P_NRORG'       => (int) $row['NRORG'],
            'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
            'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
            'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
            'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
            'P_NRESTRUTSIND' => null,
            'P_NRESTRUTTOMAD' => null,
            'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

    return $query->fetchAll();
    }

    public function getTotalAcidentesGerenOcup(
        $row
   ) {

       $sql = <<<SQL
       SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH AS INDICADOR , COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTGEREN
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

   $query = $this->connection->prepare($sql);
   $query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

   return $query->fetchAll();
   }

   public function getTotalAcidentesOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
   SELECT OH.NMOCUPACAOH AS OCUPACAO,
         COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  OH.NMOCUPACAOH
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalAcidentesPorGravidadeLegalOcupacao(
    $row
) {

   $sql = <<<SQL
   SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH || ' || Gravidade: ' || GR.NMGRAVIDADE AS INDICADOR, COUNT(1) AS QTD_ACIDENTES, GR.NMGRAVIDADE as GRAVIDADE
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_GRAVIDADE GR
    ON GR.NRORG = VI.NRORG
        AND GR.NRGRAVIDADE = OC.NRGRAVIDADE
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH, GR.NMGRAVIDADE
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalAcidentesPorGravidadeGerenOcup(
    $row
) {

   $sql = <<<SQL
   SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH || ' || Gravidade: ' || GR.NMGRAVIDADE AS INDICADOR , COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_GRAVIDADE GR
    ON GR.NRORG = VI.NRORG
        AND GR.NRGRAVIDADE = OC.NRGRAVIDADE
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTGEREN
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH, GR.NMGRAVIDADE
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );
return $query->fetchAll();
}

public function getTotalAcidentesPorGravidadeOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
   SELECT 'Gravidade: ' || GR.NMGRAVIDADE || ' || Ocupação: ' || OH.NMOCUPACAOH AS OCUPACAO, COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_GRAVIDADE GR
    ON GR.NRORG = VI.NRORG
        AND GR.NRGRAVIDADE = OC.NRGRAVIDADE
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  OH.NMOCUPACAOH, GR.NMGRAVIDADE
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}
public function getQuantidadeDiasAfastadosLegalOcup(
    $row
) {

   $sql = <<<SQL
   SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' - ' || OH.NMOCUPACAOH AS INDICADOR, SUM(ASF.NRQTDIASITUFUNC) AS QTD_AFASTAMENTOS
FROM GPE_ALTESITUFUNC ASF
JOIN GPE_VINCULOM VM
    ON VM.NRORG = ASF.NRORG
        AND ASF.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
JOIN GPE_SITUFUNCM SF
    ON SF.NRSITUFUNCM = ASF.NRSITUFUNCM
JOIN GPE_SITUFUNCH SFH
    ON SFH.NRSITUFUNCM = SF.NRSITUFUNCM
        AND SFH.DTEFETIVA = 
    (SELECT MAX(DTEFETIVA)
    FROM GPE_SITUFUNCH
    WHERE GPE_SITUFUNCH.DTEFETIVA <= :P_DTMESCOMPETENC
            AND GPE_SITUFUNCH.NRSITUFUNCM = SFH.NRSITUFUNCM
            AND GPE_SITUFUNCH.NRORG = SFH.NRORG)
WHERE ASF.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
        AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (SFH.IDAFASTSITUFUNC = 'S' /*Situacao funcional que gere afastamento*/
        OR SF.NRSITUFUNCM IN (12, 100012, 15, 16, 100084, 3, 5, 11))/*Atestados médico e odontológico, Afastamentos 15 dias empregador*/
        AND SF.NRSITUFUNCM <> 13 /*Demitito eh parametrizado como gera afastamento mas nao gera o evento*/
GROUP BY  EM.NMESTRUTURAM , OH.NMOCUPACAOH
HAVING SUM(ASF.NRQTDIASITUFUNC) IS NOT NULL
ORDER BY QTD_AFASTAMENTOS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getQuantidadeDiasAfastadosOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
   SELECT OH.NMOCUPACAOH AS INDICADOR, SUM(ASF.NRQTDIASITUFUNC) AS QTD_AFASTAMENTOS
FROM GPE_ALTESITUFUNC ASF
JOIN GPE_VINCULOM VM
    ON VM.NRORG = ASF.NRORG
        AND ASF.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
JOIN GPE_SITUFUNCM SF
    ON SF.NRSITUFUNCM = ASF.NRSITUFUNCM
JOIN GPE_SITUFUNCH SFH
    ON SFH.NRSITUFUNCM = SF.NRSITUFUNCM
        AND SFH.DTEFETIVA = 
    (SELECT MAX(DTEFETIVA)
    FROM GPE_SITUFUNCH
    WHERE GPE_SITUFUNCH.DTEFETIVA <= :P_DTMESCOMPETENC
            AND GPE_SITUFUNCH.NRSITUFUNCM = SFH.NRSITUFUNCM
            AND GPE_SITUFUNCH.NRORG = SFH.NRORG)
WHERE ASF.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
        AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (SFH.IDAFASTSITUFUNC = 'S' /*Situacao funcional que gere afastamento*/
        OR SF.NRSITUFUNCM IN (12, 100012, 15, 16, 100084, 3, 5, 11))/*Atestados médico e odontológico, Afastamentos 15 dias empregador*/
        AND SF.NRSITUFUNCM <> 13 /*Demitito eh parametrizado como gera afastamento mas nao gera o evento*/
GROUP BY  OH.NMOCUPACAOH
HAVING SUM(ASF.NRQTDIASITUFUNC) IS NOT NULL
ORDER BY QTD_AFASTAMENTOS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalPartesDoCorpoAtingidasLegalOcup(
    $row
) {

   $sql = <<<SQL
   SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH || ' || Parte Atingida: ' || PA.NMPARTEATINGIDA AS INDICADOR, COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_VITIMAPARTEATINGIDA VPA
    ON VPA.NRORG = VI.NRORG
        AND VPA.NROCORRENCIA = VI.NROCORRENCIA
        AND VPA.NRVITIMA = VI.NRVITIMA
JOIN SST_PARTEATINGIDA PA
    ON VPA.NRPARTEATINGIDA = PA.NRPARTEATINGIDA
        AND PA.NRORG = VPA.NRORG
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH, PA.NMPARTEATINGIDA
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalPartesDoCorpoAtingidasOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
   SELECT 'Ocupação: ' || OH.NMOCUPACAOH || ' || Parte Atingida: ' || PA.NMPARTEATINGIDA AS INDICADOR, COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_VITIMAPARTEATINGIDA VPA
    ON VPA.NRORG = VI.NRORG
        AND VPA.NROCORRENCIA = VI.NROCORRENCIA
        AND VPA.NRVITIMA = VI.NRVITIMA
JOIN SST_PARTEATINGIDA PA
    ON VPA.NRPARTEATINGIDA = PA.NRPARTEATINGIDA
        AND PA.NRORG = VPA.NRORG
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  OH.NMOCUPACAOH, PA.NMPARTEATINGIDA
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getSituacaoGeradoraAcidenteLegalOcup(
    $row
) {

   $sql = <<<SQL
   SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH || ' || Situação Geradora: ' || SG.DSSITUGERADORA AS INDICADOR, COUNT(1) AS QTD_ACIDENTES 
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
LEFT JOIN SST_TIPOOCORRE TPO
    ON TPO.NRORG = OC.NRORG
        AND TPO.NRTIPOOCORRE = OC.NRTIPOOCORRE
LEFT JOIN SST_SITUGERADORA SG
    ON SG.NRSITUGERADORA = TPO.NRSITUGERADORA AND(SG.NRORG = TPO.NRORG
        OR SG.NRORG = 0)
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC = 
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH, SG.DSSITUGERADORA
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getSituacaoGeradoraAcidenteOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
    SELECT 'Ocupação: ' || OH.NMOCUPACAOH || ' || Situação Geradora ' || SG.DSSITUGERADORA AS INDICADOR, 
           COUNT(1) AS QTD_ACIDENTES,
           ROW_NUMBER() OVER (ORDER BY COUNT(1) DESC) AS rank_order
    FROM SST_VITIMA VI
    JOIN SST_OCORRENCIA OC ON OC.NRORG = VI.NRORG AND OC.NROCORRENCIA = VI.NROCORRENCIA
    LEFT JOIN SST_TIPOOCORRE TPO ON TPO.NRORG = OC.NRORG AND TPO.NRTIPOOCORRE = OC.NRTIPOOCORRE
    LEFT JOIN SST_SITUGERADORA SG ON SG.NRSITUGERADORA = TPO.NRSITUGERADORA 
                                   AND (SG.NRORG = TPO.NRORG OR SG.NRORG = 0)
    JOIN GPE_PESSOA PE ON PE.NRORG = VI.NRORG AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
    JOIN GPE_VINCULOM VM ON VM.NRORG = VI.NRORG AND VM.NRPESSOA = PE.NRPESSOA
    JOIN GPE_VINCULOH VH ON VH.NRORG = VI.NRORG AND VH.NRVINCULOM = VM.NRVINCULOM
                         AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC)
                                                FROM GPE_VINCULOH H1
                                                WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND H1.NRORG = VM.NRORG
                                                  AND H1.NRVINCULOM = VM.NRVINCULOM)
    LEFT JOIN GPE_ALTEOCUPACAO AO ON AO.NRORG = VM.NRORG AND AO.NRVINCULOM = VM.NRVINCULOM
                                 AND AO.DTINIOCUPACAO = (SELECT MAX(DTINIOCUPACAO)
                                                       FROM GPE_ALTEOCUPACAO
                                                       WHERE NRORG = VM.NRORG
                                                         AND NRVINCULOM = VM.NRVINCULOM
                                                         AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
    LEFT JOIN GPE_OCUPACAOH OH ON AO.NROCUPACAOM = OH.NROCUPACAOM
                               AND OH.NRORG = AO.NRORG
                               AND OH.DTMESCOMPETENC = (SELECT MAX(OHH.DTMESCOMPETENC)
                                                      FROM GPE_OCUPACAOH OHH
                                                      WHERE OHH.NRORG = :P_NRORG
                                                        AND OHH.NROCUPACAOM = OH.NROCUPACAOM
                                                        AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
    LEFT JOIN TIPOHIERARQORG TH ON (TH.NRORG = VM.NRORG OR TH.NRORG = 0)
                               AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
                               AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
    LEFT JOIN HIERARQUIAORG HO ON HO.NRORG = VM.NRORG
                              AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
                              AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
                              AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
                              AND (HO.DTFIMVIGENCIA IS NULL OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
                              AND HO.DTINIVIGENCIA = (SELECT MAX(DTINIVIGENCIA)
                                                     FROM HIERARQUIAORG HI
                                                     WHERE HI.NRORG = HO.NRORG
                                                       AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
                                                       AND HI.NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
                                                       AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
                                                       AND (HI.DTFIMVIGENCIA IS NULL OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
    LEFT JOIN ESTRUTURAM EMSUP ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
                               AND EMSUP.NRORG = HO.NRORG
    WHERE VI.NRORG = :P_NRORG
      AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL OR :P_NRESTRUTLEGAL IS NULL)
      AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
      AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND OR :P_NRESTRUTSIND IS NULL)
      AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD OR :P_NRESTRUTTOMAD IS NULL)
      AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
    GROUP BY OH.NMOCUPACAOH, SG.DSSITUGERADORA
    ORDER BY QTD_ACIDENTES DESC
    OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalEpisEntreguesLegalOcupDashboard(
    $row
) 
{
    $sql = <<<SQL
    SELECT COUNT(*) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE HE.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalEpisEntreguesLegalOcup(
    $row
) {
   $sql = <<<SQL
    SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' - ' || OH.NMOCUPACAOH AS INDICADOR, COUNT(1) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE HE.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
GROUP BY  EM.NMESTRUTURAM , OH.NMOCUPACAOH
ORDER BY QTD_EPIS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalEpisEntreguesGerenOcup(
    $row
) {

   $sql = <<<SQL
    SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' - ' || OH.NMOCUPACAOH AS INDICADOR, COUNT(1) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTGEREN
    AND EM.NRORG = VH.NRORG
WHERE HE.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
GROUP BY  EM.NMESTRUTURAM , OH.NMOCUPACAOH
ORDER BY QTD_EPIS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}


public function getTotalEpisEntreguesOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
    SELECT OH.NMOCUPACAOH AS OCUPACAO,
         COUNT(1) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1 )
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
WHERE HE.NRORG = :P_NRORG AND(VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
GROUP BY  OH.NMOCUPACAOH
ORDER BY QTD_EPIS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalEpisEntreguesVencidoLegalOcupacao(
    $row
) {

   $sql = <<<SQL
    SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' - ' || OH.NMOCUPACAOH AS INDICADOR, COUNT(1) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE HE.NRORG = :P_NRORG AND(VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND HE.DTVALIDADEEPI <= LAST_DAY(:P_DTMESCOMPETENC)
        AND HE.DTVALIDADEEPI IS NOT NULL
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH
ORDER BY QTD_EPIS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalEpisEntreguesVencidoGerenOcup(
    $row
) {

   $sql = <<<SQL
    SELECT 'Estrutura: ' || EM.NMESTRUTURAM|| ' - ' || OH.NMOCUPACAOH AS INDICADOR, COUNT(1) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTGEREN
    AND EM.NRORG = VH.NRORG
WHERE HE.NRORG = :P_NRORG AND(VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND HE.DTVALIDADEEPI <= LAST_DAY(:P_DTMESCOMPETENC)
        AND HE.DTVALIDADEEPI IS NOT NULL
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH
ORDER BY QTD_EPIS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}


public function getTotalEpisEntreguesVencidoOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
    SELECT OH.NMOCUPACAOH AS OCUPACAO,
         COUNT(1) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1 )
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
WHERE HE.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND HE.DTVALIDADEEPI <= LAST_DAY(:P_DTMESCOMPETENC)
        AND HE.DTVALIDADEEPI IS NOT NULL
GROUP BY  OH.NMOCUPACAOH
ORDER BY QTD_EPIS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}


public function getTotalEpisEntreguesCAVencidoLegalOcup(
    $row
) {

   $sql = <<<SQL
    SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' - ' || OH.NMOCUPACAOH AS INDICADOR, COUNT(1) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE HE.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND HE.DTVALIDADEEPI <= LAST_DAY(:P_DTMESCOMPETENC)
        AND HE.DTVALIDADEEPI IS NOT NULL
        AND HE.NRCTRLAPROVEPI IS NOT NULL
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH
ORDER BY QTD_EPIS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getTotalEpisEntreguesCAVencidoGerenOcup(
    $row
) {

   $sql = <<<SQL
    SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' - ' || OH.NMOCUPACAOH AS INDICADOR, COUNT(1) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTGEREN
    AND EM.NRORG = VH.NRORG
WHERE HE.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND HE.DTVALIDADEEPI <= LAST_DAY(:P_DTMESCOMPETENC)
        AND HE.DTVALIDADEEPI IS NOT NULL
        AND HE.NRCTRLAPROVEPI IS NOT NULL
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH
ORDER BY QTD_EPIS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}


public function getTotalEpisEntreguesCAVencidoOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
    SELECT OH.NMOCUPACAOH AS OCUPACAO,
         COUNT(1) AS QTD_EPIS
FROM SST_HISTORICOEPI HE
JOIN GPE_VINCULOM VM
    ON HE.NRORG = VM.NRORG
        AND HE.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1 )
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY') )
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
WHERE HE.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || VH.NRESTRUTGEREN || ',') > 0)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND HE.DTVALIDADEEPI <= LAST_DAY(:P_DTMESCOMPETENC)
        AND HE.DTVALIDADEEPI IS NOT NULL
        AND HE.NRCTRLAPROVEPI IS NOT NULL
GROUP BY  OH.NMOCUPACAOH
ORDER BY QTD_EPIS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRTIPOESTRUTOMADOR' => $row['NRTIPOESTRUTOMADOR'],
        'P_NRESTRUTLEGAL' => $row['NRESTRUTLEGAL'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        'P_NRESTRUTSIND' => null,
        'P_NRESTRUTTOMAD' => null,
        'P_NRTIPOESTRUTGEREN' => $row['NRTIPOESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}
public function getTotalReuniaoAnoDashboard(
    $row
) {

   $sql = <<<SQL
SELECT 
    NVL(COUNT(GR.NRTIPOREUNIAO), 0) AS TOTAL,
    TO_CHAR(TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'), 'YYYY') AS DTDATA
FROM 
    GPE_REUNIAO GR
WHERE 
    TO_CHAR(GR.DTHRPREVINIREUNIAO, 'YYYY') = TO_CHAR(TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'), 'YYYY')
    AND GR.NRORG = :P_NRORG 
    AND (:P_NRESTRUTGEREN IS NULL 
        OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || GR.NRESTRUTURAM || ',') > 0)
GROUP BY 
    TO_CHAR(TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'), 'YYYY')

SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}

public function getReuniaoPorMes(
    $row
) {

   $sql = <<<SQL
    SELECT NVL(COUNT(GR.NRTIPOREUNIAO),
         0) AS TOTAL,
         TO_CHAR(DT.DTDATA,
         'MM/YYYY') AS DTDATA
FROM DATA DT
LEFT JOIN GPE_REUNIAO GR
    ON TO_CHAR(DT.DTDATA, 'MM/YYYY') = TO_CHAR(GR.DTHRPREVINIREUNIAO, 'MM/YYYY')
        AND GR.NRORG = :P_NRORG AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || GR.NRESTRUTURAM || ',') > 0)
LEFT JOIN GPE_TIPOREUNIAO TR
    ON GR.NRTIPOREUNIAO = TR.NRTIPOREUNIAO
        AND GR.NRORG = TR.NRORG
WHERE DT.DTDATA = TRUNC(DT.DTDATA, 'MM')
        AND DT.DTDATA
    BETWEEN ADD_MONTHS(:P_DTMESCOMPETENC, - 11)
        AND :P_DTMESCOMPETENC
GROUP BY  TO_CHAR(DT.DTDATA, 'MM/YYYY')
ORDER BY  TO_DATE(TO_CHAR(DT.DTDATA, 'MM/YYYY'), 'MM/YYYY')
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN'],
        )
    );

return $query->fetchAll();
}


public function getReuniaoPorAno(
    $row
) {

   $sql = <<<SQL
    SELECT NVL(COUNT(GR.NRTIPOREUNIAO),
         0) AS TOTAL,
         TO_CHAR(DT.DTDATA,
         'YYYY') AS DTDATA
FROM DATA DT
LEFT JOIN GPE_REUNIAO GR
    ON TO_CHAR(DT.DTDATA, 'YYYY') = TO_CHAR(GR.DTHRPREVINIREUNIAO, 'YYYY')
        AND GR.NRORG = :P_NRORG AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || GR.NRESTRUTURAM || ',') > 0)
LEFT JOIN GPE_TIPOREUNIAO TR
    ON GR.NRTIPOREUNIAO = TR.NRTIPOREUNIAO
        AND GR.NRORG = TR.NRORG
WHERE DT.DTDATA = TRUNC(DT.DTDATA, 'YYYY')
        AND DT.DTDATA
    BETWEEN ADD_MONTHS(:P_DTMESCOMPETENC, -120)
        AND :P_DTMESCOMPETENC
GROUP BY  TO_CHAR(DT.DTDATA, 'YYYY')
ORDER BY  TO_DATE(TO_CHAR(DT.DTDATA, 'YYYY'), 'YYYY')
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_DTMESCOMPETENC'   => $row['DTMESCOMPETENC'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN']
        )
    );

return $query->fetchAll();
}

public function getTotalReuniaoPorTipoReuniao(
    $row
) {

   $sql = <<<SQL
    SELECT COUNT(1) AS QTD_REUNIOES,
         'Comitê: ' || CM.NMCOMITE || ' || Tipo de reunião: ' || TR.NMTIPOREUNIAO AS INDICADOR
FROM GPE_REUNIAO GR
JOIN GPE_COMITE CM
    ON CM.NRCOMITE = GR.NRCOMITE
        AND CM.NRORG = GR.NRORG
JOIN GPE_TIPOREUNIAO TR
    ON GR.NRTIPOREUNIAO = TR.NRTIPOREUNIAO
        AND GR.NRORG = TR.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = GR.NRESTRUTURAM
    AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || GR.NRESTRUTURAM || ',') > 0)
        AND GR.NRORG = EM.NRORG WHERE(GR.NRORG = :P_NRORG) AND (:P_NRESTRUTGEREN IS NULL OR INSTR(',' || :P_NRESTRUTGEREN || ',', ',' || GR.NRESTRUTURAM || ',') > 0)
GROUP BY  TR.NMTIPOREUNIAO, CM.NMCOMITE
ORDER BY QTD_REUNIOES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
    array(
        'P_NRORG'       => (int) $row['NRORG'],
        'P_NRESTRUTGEREN' => $row['NRESTRUTGEREN']
        )
    );

return $query->fetchAll();
}

}