<?php

namespace Ems\Services;

use Ems\Repository\EscalaRepository;
use Util\Environment;

class EscalaService {
    /** @var Environment */
    protected $environment;

    /** @var EscalaRepository */
    protected $escalaRepository;
    
    const IDTIPOHORARIO_TURNO = 'T';

    public function __construct(
        Environment         $environment,
        EscalaRepository    $escalaRepository
    ) {
        $this->environment      = $environment;
        $this->escalaRepository = $escalaRepository;
    }

    public function getEscalaTrab(
        string $dtMesCompetencia = ''
    ): array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        if ($dtMesCompetencia === '') {
            $dtMesCompetencia = $this->environment->getDtmescomptencDiaCorrente();
        }

        $params = [
            'P_NRORG'           => $nrOrg,
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_DTMESCOMPETENC'  => $dtMesCompetencia,
        ];

        $escalas = $this->escalaRepository->getEscalaTrab($params);

        return $escalas;
    }

    public function getTurnos(
        int $nrEscala
    ): array {
        $nrOrg = (int) $this->environment->getNrOrg();

        $params = [
            'P_NRORG'           => $nrOrg,
            'P_NRESCALATRABM'   => $nrEscala,
        ];

        $turnos = $this->escalaRepository->getTurnos($params);

        return $turnos;
    }

    public function getTurnoParOuImpar(
        string $nrEscalaTrabm,
        string $diaReferencia,
        int $number
    ): array {
        $nrOrg = (int) $this->environment->getNrOrg();

        $params = [
            'P_NRORG'         => $nrOrg,
            'P_NRESCALATRABM' => $nrEscalaTrabm,
            'P_NUMBER'        => $number,
            'P_DIA'          => $diaReferencia
        ];

        $escalas = $this->escalaRepository->getTurnoParOuImpar($params);

        return $escalas;
    }

}
