<?php

namespace Eso\Controllers;

use Doctrine\ORM\EntityManager;
use Eso\Logic\ESocialLogic;
use HCM\Util\Repositories;
use Util\DateUtil;
use Util\Environment;
use Util\HcmServices;
use Util\Messages;
use Util\Util;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;

class EsoSimplificadoController {

    public function __construct (EntityManager $entityManager, Environment $environment, HcmServices $hcmservices){
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->hcmservices = $hcmservices;
    }

    public function processaFilaPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $eventos = array();

            $row = $request->getRow();

            $nrorg = $row['NRORG'];
            $cdoperador = $row['CDOPERADOR'];
            $dtmescompetenc = $row['DTMESCOMPETENC'];
            $nrestruturam = $row["NRESTRUTURAM"];
            $nrtpambiente = $row["NRTPAMBIENTE"];
            $nmevento = $row['NMEVENTO'];
            $nresoconsumer = $row['NRESOCONSUMER'];

            $this->environment->setCdOperador($cdoperador);
            $this->environment->setDtCompetencia($dtmescompetenc);

            Util::writeLogFile($this->environment->getNrOrgTrab(), "start processaFilaPeriodico","consumer$nresoconsumer");

            $lote = $this->entityManager->getRepository(Repositories::ESO_LOTE)->getProximoLoteFila($nrorg, $nresoconsumer);
            if ($lote) {
                $nrlote = $lote['NRLOTE'];
                $nrenvio = $lote['NRENVIO'];

                // Marcar o lote como 'processamento'
                /*Util::writeLogFile($this->environment->getNrOrgTrab(), "status processamento (Lote:$nrlote Envio: $nrenvio)","consumer$nresoconsumer");
                $this->entityManager->getRepository(Repositories::ESO_LOTE)->atualizaStatusLoteProcessamento($nrorg, $cdoperador, $nresoconsumer, $nrlote, $nrenvio);*/

                $eventos[] = $nrenvio;

                /*$envios = $this->getEventosLote($nrorg, $nresoconsumer, $nrlote);
                foreach ($envios as $envio) {
                    $eventos[] = $envio['NRENVIO'];
                }*/

                // Chama o próprio Hcmservices
                $uri = 'enviarLoteEventoPeriodico';
                $params = array(
                    'requestType' => 'Row',
                    'row' => array(
                        "NRORG" => $nrorg,
                        "CDOPERADOR" => $cdoperador,
                        "DTMESCOMPETENC" => $dtmescompetenc,
                        "NRESTRUTURAM" => $nrestruturam,
                        "NRTPAMBIENTE" => $nrtpambiente,
                        "NMEVENTO" => $nmevento,
                        "NRESOCONSUMER" => $nresoconsumer,
                        "NRLOTE" => $nrlote,
                        "EVENTOS" => $eventos,
                    )
                );
                try {
                    Util::writeLogFile($this->environment->getNrOrgTrab(), "processaFilaPeriodico->enviarLoteEventoPeriodico (Lote:$nrlote Eventos:".implode(',', $eventos).")","consumer$nresoconsumer");

                    $result = $this->hcmservices->sendAsync($uri, $params, $nrorg);

                    Util::writeLogFile($this->environment->getNrOrgTrab(), "status concluido (Lote:$nrlote Envio: $nrenvio)","consumer$nresoconsumer");
                    $this->entityManager->getRepository(Repositories::ESO_LOTE)->atualizaStatusLoteConcluido($nrorg, $cdoperador, $nresoconsumer, $nrlote, $nrenvio);
                } catch (\Exception $e) {
                    if (strpos($e->getMessage(), 'cURL error 28') === false) {
                        Util::writeLogFile($this->environment->getNrOrgTrab(), "error processaFilaPeriodico->enviarLoteEventoPeriodico [Code:" . $e->getCode() . " Message:" . $e->getMessage() . "]", "consumer$nresoconsumer");
                        if ($e->getCode() == 500 || $e->getCode() == 50) { //500 Internal Server Error / 50 Erro de comunicação com o eSocial
                            Util::writeLogFile($this->environment->getNrOrgTrab(), "enfileira Envio (Lote:$nrlote Envio: $nrenvio","consumer$nresoconsumer");
                            $this->entityManager->getRepository(Repositories::ESO_LOTE)->enfileiraEnvio($nrorg, $nrlote, $nresoconsumer, $nrenvio, $nmevento, $cdoperador);
                        } else {
                            Util::writeLogFile($this->environment->getNrOrgTrab(), "status erro (Lote:$nrlote Envio: $nrenvio","consumer$nresoconsumer");
                            $this->entityManager->getRepository(Repositories::ESO_LOTE)->atualizaStatusLoteErro($nrorg, $cdoperador, $nresoconsumer, $nrlote, $nrenvio);
                            throw $e;
                        }
                    } else {
                        if (strpos($e->getMessage(), 'Resolving timed out after') === true) {
                            Util::writeLogFile($this->environment->getNrOrgTrab(), "catch processaFilaPeriodico->enviarLoteEventoPeriodico (Lote:$nrlote Envio: $nrenvio) [Code:" . $e->getCode() . " Message:" . $e->getMessage() . "]", "consumer$nresoconsumer");
                            Util::writeLogFile($this->environment->getNrOrgTrab(), "enfileira Envio (Lote:$nrlote Envio: $nrenvio","consumer$nresoconsumer");
                            $this->entityManager->getRepository(Repositories::ESO_LOTE)->enfileiraEnvio($nrorg, $nrlote, $nresoconsumer, $nrenvio, $nmevento, $cdoperador);
                        }
                    }
                }

                // Chama o próprio Hcmservices para continuar a fila
                $uri = 'processaFilaPeriodico';
                $params = array(
                    'requestType' => 'Row',
                    'row' => array(
                        "NRORG" => $row["NRORG"],
                        "CDOPERADOR" => $row["CDOPERADOR"],
                        "DTMESCOMPETENC" => $row["DTMESCOMPETENC"],
                        "NRESTRUTURAM" => $row["NRESTRUTURAM"],
                        "NRTPAMBIENTE" => $row["NRTPAMBIENTE"],
                        "NMEVENTO" => $row["NMEVENTO"],
                        "NRESOCONSUMER" => $row["NRESOCONSUMER"],
                    )
                );
                try {
                    Util::writeLogFile($this->environment->getNrOrgTrab(), "processaFilaPeriodico (Lote:$nrlote Envio: $nrenvio)->processaFilaPeriodico","consumer".$nresoconsumer);
                    $result = $this->hcmservices->sendAsync($uri, $params, $nrorg);
                } catch (\Exception $e) {
                    if (strpos($e->getMessage(), 'cURL error 28') === false) {
                        Util::writeLogFile($this->environment->getNrOrgTrab(), 'error processaFilaPeriodico->processaFilaPeriodico [Code:'.$e->getCode().' Message:'.$e->getMessage().']',"consumer".$nresoconsumer);
                        if ($e->getCode() == 500) { //500 Internal Server Error

                        } else {
                            throw $e;
                        }
                    } else {
                        if (strpos($e->getMessage(), 'Resolving timed out after') === true) {
                            Util::writeLogFile($this->environment->getNrOrgTrab(), "catch processaFilaPeriodico->enviarLoteEventoPeriodico (Lote:$nrlote Envio: $nrenvio) [Code:" . $e->getCode() . " Message:" . $e->getMessage() . "]", "consumer$nresoconsumer");
                            Util::writeLogFile($this->environment->getNrOrgTrab(), "enfileira Envio (Lote:$nrlote Envio: $nrenvio","consumer$nresoconsumer");
                            $this->entityManager->getRepository(Repositories::ESO_LOTE)->enfileiraEnvio($nrorg, $nrlote, $nresoconsumer, $nrenvio, $nmevento, $cdoperador);
                        }
                    }
                }

                Util::writeLogFile($this->environment->getNrOrgTrab(), 'finished processaFilaPeriodico',"consumer".$nresoconsumer);
            } else {
                Util::writeLogFile($this->environment->getNrOrgTrab(), 'conclui Consumidor',"consumer".$nresoconsumer);
                $this->entityManager->getRepository(Repositories::ESO_CONSUMER)->concluiEsoConsumer($nrorg, $nresoconsumer);
            }
        } catch(\Exception $e) {
            Util::writeLogFile($this->environment->getNrOrgTrab(), 'error processaFilaPeriodico ['.$e->getCode().' => '.$e->getMessage().']',"consumer".$nresoconsumer);
            if ($e->getCode() == 500) { //500 Internal Server Error

            } else if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }

    /**
     * @param Request\Row $request
     * @param DTO\Response $response
     */
    public function enviarLoteEventoPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $msgValidacao = array();
            $msgRetorno = "";
            
            $row = $request->getRow();

            $nrorg = $row['NRORG'];
            $cdoperador = $row['CDOPERADOR'];
            $dtmescompetenc = $row['DTMESCOMPETENC'];
            $nresoconsumer = $row['NRESOCONSUMER'];
            $nmevento = $row['NMEVENTO'];
            $nrlote = $row['NRLOTE'];
            $eventos = $row['EVENTOS'];

            $lote = current($this->entityManager->getRepository(Repositories::ESO_LOTE)->getEventosLote($nrorg, $nresoconsumer, $nrlote));

            if ($lote['IDSITUACAO'] == 'PENDENTE') {

                Util::writeLogFile($this->environment->getNrOrgTrab(), "status processamento (Lote:$nrlote)", "consumer$nresoconsumer");
                $this->entityManager->getRepository(Repositories::ESO_LOTE)->atualizaStatusLoteProcessamento($nrorg, $cdoperador, $nresoconsumer, $nrlote, $eventos[0]);

                $this->environment->setCdOperador($cdoperador);
                $this->environment->setDtCompetencia($dtmescompetenc);

                $logfile = Util::writeLogFile($this->environment->getNrOrgTrab(), "start enviarLoteEventoPeriodico (Lote:$nrlote)", "consumer" . $nresoconsumer);

                $logic = new ESocialLogic($this->entityManager, $this->environment, $dtmescompetenc, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->preparaEnviarLoteEvento(ESocialLogic::IDGRUPO_PERIODICO, $eventos, $nrlote, $nresoconsumer, $logfile);
                $msgValidacao = $logic->getMessages();

                Util::writeLogFile($this->environment->getNrOrgTrab(), "status concluido (Lote:$nrlote)", "consumer$nresoconsumer");
                $this->entityManager->getRepository(Repositories::ESO_LOTE)->atualizaStatusLoteConcluido($nrorg, $cdoperador, $nresoconsumer, $nrlote);

                if (count($msgValidacao) > 0) {
                    Util::writeLogFile($this->environment->getNrOrgTrab(), "finished enviarLoteEventoPeriodico msgValidacao (Lote:$nrlote)", "consumer" . $nresoconsumer);
                    $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('enviarLoteEventoPeriodico', $msgValidacao));
                } elseif ($msgRetorno) {
                    Util::writeLogFile($this->environment->getNrOrgTrab(), "finished enviarLoteEventoPeriodico $msgRetorno (Lote:$nrlote) $msgRetorno", "consumer" . $nresoconsumer);
                    $response->addMessage(new DTO\Response\Message($msgRetorno));
                } else {
                    Util::writeLogFile($this->environment->getNrOrgTrab(), "finished enviarLoteEventoPeriodico (Lote:$nrlote) Envio de evento não disponível", "consumer" . $nresoconsumer);
                    $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
                }

            }
        } catch(\Exception $e) {
            Util::writeLogFile($this->environment->getNrOrgTrab(), 'error enviarLoteEventoPeriodico ('.$e->getCode().'-'.$e->getMessage().')',"consumer".$nresoconsumer);
            if ($e->getCode() != 500 && $e->getCode() != 50) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                foreach ($eventos as $nrenvio) {
                    Util::writeLogFile($this->environment->getNrOrgTrab(), "enfileira Envio (Lote:$nrlote Envio: $nrenvio","consumer$nresoconsumer");
                    $this->entityManager->getRepository(Repositories::ESO_LOTE)->enfileiraEnvio($nrorg, $nrlote, $nresoconsumer, $nrenvio, $nmevento, $cdoperador);
                }
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function consultarProtocoloPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            
            $row = $request->getRow();
            
            $this->environment->setCdOperador($row['CDOPERADOR']);
            $this->environment->setDtCompetencia($row['DTMESCOMPETENC']);
                
            $logic = new ESocialLogic($this->entityManager, $this->environment, $row['DTMESCOMPETENC'], $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $logfile = Util::writeLogFile($this->environment->getNrOrgTrab(), 'called consultarProtocoloPeriodico',"consumer".$row['NRESOCONSUMER']);
            $msgRetorno = $logic->preparaConsultarLoteEvento(ESocialLogic::IDGRUPO_PERIODICO, $row, $row['NRESOCONSUMER'], $logfile);
            $msgValidacao = $logic->getMessages();
            
            if ($msgValidacao) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('consultarProtocoloPeriodico', array($msgValidacao)));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Consulta de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }

            $logfile = Util::writeLogFile($this->environment->getNrOrgTrab(), 'finished consultarProtocoloPeriodico',"consumer".$row['NRESOCONSUMER']);
        } catch(\Exception $e) {
            Util::writeLogFile($this->environment->getNrOrgTrab(), 'error consultarProtocoloPeriodico ('.$e->getMessage().')',"consumer".$row['NRESOCONSUMER']);
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
}