<?php

namespace HCM\FPA\ObrigacaoLegal\Dirf;

use HCM\Geral\Entity\GpevinculomEntity;
use HCM\FPA\Entity\FpacalculofolhaEntity;
use HCM\FPA\Entity\FpadirfmagnetEntity;
use HCM\FPA\ObrigacaoLegal\Dirf\Dirf2021;
use HCM\FPA\ObrigacaoLegal\Dirf\QueryDirf;
use HCM\FPA\ObrigacaoLegal\Dirf\Registros\RegistroDIRF;
use HCM\FPA\ObrigacaoLegal\Dirf\Registros\RegistroRESPO;
use HCM\FPA\ObrigacaoLegal\Dirf\Registros\RegistroDECPJ;
use HCM\Util\DateUtil;
use HCM\Util\FPA;
use HCM\Util\MsgCalculo;
use HCM\Util\Repositories;

class PercorreDirf {

    private $_objMagnetico;

    public function __construct($entityManager, $hcmParameters, $dataSet){
        $this->entityManager   = $entityManager;
        $this->hcmParameters   = $hcmParameters;
        $this->_nrOrg          = $hcmParameters->getNrorgTrabalho();
        $this->_nrOrgPadrao    = $hcmParameters->getNrorgPadrao();
        $this->_cdOperador     = $hcmParameters->getCdOperador();
        $this->_dtCompetencia  = $hcmParameters->getDtCompetencia();
        $this->_mesCompetencia = DateUtil::getDataDeString($hcmParameters->getDtCompetencia(), DateUtil::FORMATO_BRASILEIRO, true);

        $this->_vinculom = new GpevinculomEntity($entityManager, $hcmParameters);
        $this->_calculoFolha = new FpacalculofolhaEntity($entityManager, $hcmParameters);

        $this->_inicializaVariaveis($dataSet);

        $this->_objMagnetico = new FpadirfmagnetEntity($this->entityManager, $this->hcmParameters, $this->_nrOrg, $this->_mesCompetencia, $this->_nrInscEstrutResp);

        $tp_processamento = strtoupper($dataSet['TP_PROCESSAMENTO']);
        switch (strtoupper($tp_processamento)){
            case FPA::PROC_COMPETENCIA_MENSAL :
                $this->_retrocesso = false;
                break;
            case FPA::PROC_RETROCESSO :
                $this->_retrocesso = true;
                break;
            default:
                throw new \Exception('Tipo de processo '.$tp_processamento.' invalido');
        }
    }

    public function _inicializaVariaveis($dataSet) {

        $this->_registroDIRF = new RegistroDIRF();
        $this->_registroRESPO = new RegistroRESPO();
        $this->_registroDECPJ = new RegistroDECPJ();

        $this->queryDirf = new QueryDirf($this->entityManager,$this->hcmParameters);

        $this->_buscaDadosFormulario($dataSet);

        $estruturaResp = $this->entityManager->getRepository(Repositories::ESTRUTURAM)->getEstrutura($this->_nrOrg, $this->_nrEstrResponsa, $this->_mesCompetencia);
        
        if(!$estruturaResp || !$estruturaResp->historico){
            throw new \Exception("Não foi encontrada a estrutura responsável de número ".$this->_nrEstrResponsa." ou a estrutura não possuí histórico nessa competência");
        }
        
        $this->_nrInscEstrutResp = $estruturaResp->historico->getCdcnpjestrut();
        
        // Calculo
        $this->_nrCalculoFolha = current($this->_calculoFolha->carregaListaNrCalculoFolhaTodasOcorrencias(
            $this->_nrOrg, 1, $this->_mesCompetencia, $this->hcmParameters->getTipoModalidadeCalculo()
        ));
        
        $this->beneficiariosDirf = array();
        $this->registrosMagnetico = array();

    }
    
    //Função que carrega os dados do formulário. Na falha esta seta o nrOrg para -1 indicando a falha
    private function _buscaDadosFormulario($dataSet){
        $formObj = $this->entityManager->getRepository(Repositories::FPA_FORMDIRF)->findOneBy(array("nrorg" => $dataSet['NRORG'], "nrformdirf"=>$dataSet['NRFORMDIRF']));
        //Dados do formulário
        if(is_object($formObj)) {   //Somente grava os dados se encontrou o formulário segundo a Org e seu Nro
            $this->_nrForm         = $formObj->getNrformdirf();
            $this->_nmForm         = $formObj->getNmformdirf();
            $this->_idProcessaVinc = $formObj->getIdprocvinculo();
            $this->_idGeraMagnetic = $formObj->getIdgerameiomag();
            $this->_idExtinsaoEmpr = $formObj->getIdexcempresa();
            $this->_idTipoDeclarac = $formObj->getIdtipdeclaracao();
            $this->_idNaturezaDecl = $formObj->getIdnaturezadirf();
            $this->_dsOrdem        = $formObj->getDsordem();
            $this->_dsInicio       = $formObj->getNomeinicial();
            $this->_dsFim          = $formObj->getNomefinal();
            $this->_nomeInicial    = $formObj->getNomeinicial(); /*pck add 24/01/19 inicio*/
            $this->_nomeFinal      = $formObj->getNomefinal();
            $this->_dataInicial    = $formObj->getDtinicial();
            $this->_dataFinal      = $formObj->getDtfinal();
            $this->_nrEstrutuLegal = $formObj->getNrestrutlegal();
            $this->_nrEstrutuGeren = $formObj->getNrestrutgeren();
            $this->_nrMatriInicial = $formObj->getNrmatricinicial();
            $this->_nrMatricuFinal = $formObj->getNrmatricfinal(); /*pck add 24/01/19 fim*/
            $this->_nrPessResponsa = $formObj->getNrpessoarespons();
            $this->_nrEstrResponsa = $formObj->getNrestrutrespons();
            $this->_nrGrupoInciden = $formObj->getNrgrpincide();
            $this->_nrGrupoIncSaud = $formObj->getNrgrpincidsaud();
            $this->_nrRecibo       = $formObj->getNrregistro();
            $this->_idTpInscriResp = $formObj->getIdtpinscrespons();
            $this->_idSocioOstensi = $formObj->getIdsociostens();
            $this->_idDepositJudic = $formObj->getIddepojudic();
            $this->_idInstitInvest = $formObj->getIdinstinvest();
            $this->_idPagRendiExte = $formObj->getIdpagrendext();
            $this->_idPagPlanoSaud = $formObj->getIdpagplansaud();
            $this->_idPagRelacCopa = $formObj->getIdpagrelcopa();
            //$this->_idPagRelacOlimp = $formObj->getIdpagrelolimp();    //DIRF 2019
            $this->_idPagRelacOlimp = 'N';                               //DIRF 2019 - N – Não é fundação pública de direito privado
            //$this->_idPagSituaEspe = $formObj->getIdpagsitespe();      //DIRF 2019
            $this->_idPagSituaEspe = 'N';                                //DIRF 2019 - N – Não é declaração de situação especial
            $this->_dtEventoEspeci = $formObj->getDteventespec();
            $this->_anoCalendario  = $formObj->getNranocalen();
            $this->_anoReferencia  = $formObj->getNranoref();
            $this->_tdVinculos = $formObj->getIdtdvinculos();
            $this->_idVincRetencao = $formObj->getIdretvinculos();
            $this->_idVincRendimento = $formObj->getIdrendvinculos();
            $this->_vrMinRendimento = $formObj->getVrreferencia();
            $this->_idVincProLabore = $formObj->getIdprovinculos();
            $this->_idApuraBeneficio = $formObj->getIdapurabeneficio();
            $this->params = array();
            $this->params["inicio"] = $this->dsInicio;
            if($this->dsFim) {
                $this->params["fim"] = $this->dsFim;
            }
        } else {                //Formulário não encontrado
            $this->nrorg  = -1; //indica que não carregou os dados
            $this->msgErro = 'Formulário não carregado. O número do formulário '.$dataSet['NRFORMDIRF'].' da organização número '.$dataSet['NRORG'].' não foi encontrado.'.Dirf::ql_msg;
        }

    }
    
    public function percorre(){
        if ($this->_retrocesso === false) {
            $resultado = $this->_geraDIRF();
            return $resultado;
        } else {
            $this->_sefip->retroceder();
            return array("RETROCESSO" => true);
        }
    }
    
    private function retornaValorReferenciaGerando(){
        $valorReferencia = $this->entityManager->getRepository(Repositories::FPA_VALORREFERENCIAM)->retornaValorReferencia(
            $this->_nrOrg, $this->_nrOrgPadrao, $this->_mesCompetencia->format(DateUtil::FORMATO_BRASILEIRO), 'DIRF_GERANDO'
        );
        
        if ($valorReferencia && $valorReferencia[0]->getDsobservacao() == $this->_nrInscEstrutResp){
            return $valorReferencia;
        } else {
            return null;
        }
    }
    
    private function iniciaValorReferenciaGerando($datahorainicio){
        $valorReferencia = $this->retornaValorReferenciaGerando();
        
        if ($valorReferencia) {
            $difhorainicio = (int)$datahorainicio - (int)$valorReferencia[1]->getVrreferencia();
            if ($datahorainicio > $valorReferencia[1]->getVrreferencia() && $valorReferencia[1]->getVrrefvalorref() == 1) {
                throw new \Exception("Existe uma DIRF em processamento. Favor aguardar alguns minutos e tentar novamente.");
            }
            if ($this->_idGeraMagnetic == 'S' && $datahorainicio < $valorReferencia[1]->getVrreferencia() && $valorReferencia[1]->getVrrefvalorref() == 2) {
                throw new \Exception("Existe uma DIRF processada. Favor desmarcar a opção de gerar magnético no formulário e solicitar a geração novamente para gerar o arquivo.");
            }
        } else {
            $this->insertValorReferenciaGerando($datahorainicio);
        }
    }
    
    private function insertValorReferenciaGerando($datahorainicio){
        try {
            $this->entityManager->beginTransaction();
            
            $fpaValorreferenciam = Repositories::FPA_VALORREFERENCIAM;
            $fpaValorreferenciah = Repositories::FPA_VALORREFERENCIAH;
            
            $nrvalorreferenciam = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'FPA_VALORREFERENCIAM', 1, 12, true);
            $nrvalorreferenciah = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'FPA_VALORREFERENCIAH', 1, 12, true);
            
            $params = array(
                'P_NRORG' => $this->_nrOrg,
                'P_NRVALORREFERENCIAM' => $nrvalorreferenciam,
                'P_NRVALORREFERENCIAH' => $nrvalorreferenciah,
                'P_DSREFERENCIA' => 'DIRF_GERANDO',
                'P_DTINIVIGENCIA' => $this->_mesCompetencia->format('d/m/Y'),
                'P_DSOBSERVACAO' => $this->_nrInscEstrutResp,
                'P_DTMESCOMPETENC' => $this->_mesCompetencia->format('d/m/Y'),
                'P_VRREFERENCIA' => $datahorainicio,
                'P_VRREFVALORREF' => 1,
                'P_DTINCLUSAO' => DateUtil::getDataAtual()->format('d/m/Y H:i:s'),
                'P_NRORGINCLUSAO' => $this->hcmParameters->getNrorgTrabalho(),
                'P_CDOPERINCLUSAO' => $this->hcmParameters->getCdoperador(),
                'P_DTULTATU' => DateUtil::getDataAtual()->format('d/m/Y H:i:s'),
                'P_NRORGULTATU' => $this->hcmParameters->getNrorgTrabalho(),
                'P_CDOPERULTATU' => $this->hcmParameters->getCdoperador(),
            );
            
            $sql = "INSERT INTO FPA_VALORREFERENCIAM (
                        NRORG,
                        NRVALORREFERENCIAM,
                        DSREFERENCIA,
                        DTINIVIGENCIA,
                        DSOBSERVACAO,
                        DTINCLUSAO,
                        NRORGINCLUSAO,
                        CDOPERINCLUSAO,
                        DTULTATU,
                        NRORGULTATU,
                        CDOPERULTATU
                    )
                    VALUES (
                        :P_NRORG,
                        :P_NRVALORREFERENCIAM,
                        :P_DSREFERENCIA,
                        :P_DTINIVIGENCIA,
                        :P_DSOBSERVACAO,
                        :P_DTINCLUSAO,
                        :P_NRORGINCLUSAO,
                        :P_CDOPERINCLUSAO,
                        :P_DTULTATU,
                        :P_NRORGULTATU,
                        :P_CDOPERULTATU
                    )";
            \Setforms2\Shared\Registry::getEntityManagerConnection()->executeQuery($sql, $params);
            
            $sql = "INSERT INTO FPA_VALORREFERENCIAH (
                        NRORG,
                        NRVALORREFERENCIAM,
                        NRVALORREFERENCIAH,
                        DTMESCOMPETENC,
                        VRREFERENCIA,
                        VRREFVALORREF,
                        DTINCLUSAO,
                        NRORGINCLUSAO,
                        CDOPERINCLUSAO,
                        DTULTATU,
                        NRORGULTATU,
                        CDOPERULTATU
                    )
                    VALUES (
                        :P_NRORG,
                        :P_NRVALORREFERENCIAM,
                        :P_NRVALORREFERENCIAH,
                        :P_DTMESCOMPETENC,
                        :P_VRREFERENCIA,
                        :P_VRREFVALORREF,
                        :P_DTINCLUSAO,
                        :P_NRORGINCLUSAO,
                        :P_CDOPERINCLUSAO,
                        :P_DTULTATU,
                        :P_NRORGULTATU,
                        :P_CDOPERULTATU
                    )";
            \Setforms2\Shared\Registry::getEntityManagerConnection()->executeQuery($sql, $params);
            
            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            return;
        }
    }
    
    private function finalizaValorReferenciaGerando($datahorainicio){
        $valorReferencia = $this->retornaValorReferenciaGerando();
        
        if ($valorReferencia) {
            $difhorainicio = (int)$datahorainicio - (int)$valorReferencia[1]->getVrreferencia();
            if ($datahorainicio == $valorReferencia[1]->getVrreferencia() && ($difhorainicio >= 10000/*Tempo maior que 1h*/)) {
                $valorReferencia[1]->setVrrefvalorref(2);
                $this->entityManager->persist($valorReferencia[1]);
            } else {
                $this->limpaValorReferenciaGerando($valorReferencia[0], $valorReferencia[1]);
            }
        }
    }
    
    private function limpaValorReferenciaGerando($mestre, $historico){
        try {
            $params = array(
                "P_NRVALORREFERENCIAM" => $mestre->getNrvalorreferenciam(),
            );
            
            $sql = "DELETE FROM FPA_VALORREFERENCIAH WHERE NRVALORREFERENCIAM = :P_NRVALORREFERENCIAM";
            \Setforms2\Shared\Registry::getEntityManagerConnection()->executeQuery($sql, $params);
            
            $sql = "DELETE FROM FPA_VALORREFERENCIAM WHERE NRVALORREFERENCIAM = :P_NRVALORREFERENCIAM";
            \Setforms2\Shared\Registry::getEntityManagerConnection()->executeQuery($sql, $params);
        } catch (\Exception $e) {
            return;
        }
    }

    private function _geraDIRF(){

        $this->_msg_idabort = false;    
        $this->_msg_idstatus = MsgCalculo::ID_PENDENTE;
        $nrcalculomsg = $this->_nrCalculoFolha;
            
        $this->_preparaRegistroDIRF();
        $this->_preparaRegistroRESPO();
        $this->_preparaRegistroDECPJ();
        
        /*Alteracao 29/02/2024 para Renata gerar usando lote de vinculos*/
        $valorReferencia = $this->entityManager->getRepository(Repositories::FPA_VALORREFERENCIAM)->retornaValorReferencia(
            $this->_nrOrg, $this->_nrOrgPadrao, $this->_mesCompetencia->format(DateUtil::FORMATO_BRASILEIRO), 'DIRF_LOTEVINCULO'
        );
        if ($valorReferencia) {
            if ($this->hcmParameters->getCdoperador() == $valorReferencia[0]->getCdoperinclusao()) {
                $this->_dsOrdem = 'LOTE_VINCULO';
                $this->_dsInicio = $valorReferencia[1]->getVrreferencia();
            }
        }

        if ($this->_idGeraMagnetic == 'S') {
        
            $datahorainicio = DateUtil::getDataAtual()->format('YmdHis');
            
            $this->iniciaValorReferenciaGerando($datahorainicio);
            
            $registros = $this->_objMagnetico->qdeRegistros();
            if ($registros == 0) {

                if ($this->_idProcessaVinc == 'S') {
                    $this->_objMagnetico->addRegCabecal($this->_nrInscEstrutResp, null, $this->_nrPessResponsa, 'S');
                }
                
                $beneficiarios = array();
    
                $vinculos = $this->_vinculom->retornaVinculosDirf($this->_nrOrg, $this->_mesCompetencia,
                    $this->_dsInicio, $this->_dsFim, $this->_dsOrdem, $this->_tdVinculos, $this->_idVincProLabore
                );
    
                foreach ($vinculos as $vinculo) {
                    $beneficiarios[$vinculo->getNrpessoa()]= $vinculo->getNrpessoa();
                }
    
                $this->_dirf  = new Dirf2021(
                    $this->entityManager, $this->hcmParameters, $this->_objMagnetico, $this->_nrRegimeApur, $this->_dsOrdem, $this->_dsInicio, $this->_dsFim,
                    $this->_idVincRetencao, $this->_idVincRendimento, $this->_vrMinRendimento, $this->_idApuraBeneficio
                );
    
                foreach ($beneficiarios as $nrpessoa) {
                    $processamento = MsgCalculo::getInstance();
                    $processamento->setDados($nrcalculomsg, $nrpessoa, $this->_nrOrg, 'DIRF');
    
                    $nrcpfbeneficiario = $this->_dirf->geraDIRF($nrpessoa);
                    
                    if (!is_null($nrcpfbeneficiario)) {
                        $this->beneficiariosDirf[$nrcpfbeneficiario] = 1; //Armazena os CPFs dos participantes da DIRF
                    }
                    
                }
                
            } else {
                throw new \Exception('Já existe magnético da DIRF para o mês de competência, favor retroceder ou desmarcar a opção de gerar magnético para apenas fazer o download do arquivo.');
            }

        }
        
        $this->setRegistrosMagnetico();
        
        if ($this->_idGeraMagnetic == 'S' || $this->_idProcessaVinc == 'S') {
            $this->_preparaRegistroPSE();
        }
        
        if (($this->_msg_idabort == false) && ($this->_msg_idstatus !== MsgCalculo::ID_COM_ERRO)) {
            if ($this->_idProcessaVinc == 'S') {
                $this->finalizaValorReferenciaGerando($datahorainicio);
                $arquivo = $this->_geraMagnetico();
            }
        }
        
        
        return array(
            'ARQUIVO' => $arquivo,
            'CALCULO' => $nrcalculomsg,
            'ERRO' => (($this->_msg_idstatus === MsgCalculo::ID_COM_ERRO) || ($this->_msg_idstatus === MsgCalculo::ID_COM_ALERTA)),
            'ABORT' => $this->_msg_idabort
        );
    }

    private function _geraMagnetico(){

        $nomeArquivo = "DIRF_" . $this->_nrInscEstrutResp . ".txt";

        $this->_registroDIRF->geraRegistroDIRF();
        FPA::escreveArquivo($nomeArquivo, $this->_registroDIRF->getLinhaRegistro().RegistroDIRF::QUEBRA_LINHA_CR_LF, false, true);

        $this->_registroRESPO->geraRegistroRESPO();
        FPA::escreveArquivo($nomeArquivo, $this->_registroRESPO->getLinhaRegistro().RegistroDIRF::QUEBRA_LINHA_CR_LF);

        $this->_registroDECPJ->geraRegistroDECPJ();
        FPA::escreveArquivo($nomeArquivo, $this->_registroDECPJ->getLinhaRegistro().RegistroDIRF::QUEBRA_LINHA_CR_LF);
        
        $idrecAnt = -1;
        //$registros = $this->_objMagnetico->retornaRegistros();
        foreach ($this->registrosMagnetico as $item) {
            
            //Se estiver marcado no formulário para somente vinculos com rendimento superior a X
            //Se estiver marcado no formulário para somente vinculos com retenção
            if (($this->_idVincRendimento == 'S' && $item->getVrtotalrend() < $this->_vrMinRendimento) && ($this->_idVincRetencao == 'S' && $item->getVrtotimpretido() == 0)) {
                continue;
            }
            
            $idrec = substr($item->getDslinharegistro(),0,strpos($item->getDslinharegistro(),"\nBPFDEC"));
            $registro = substr($item->getDslinharegistro(),strpos($item->getDslinharegistro(),"\nBPFDEC")+1,strlen($item->getDslinharegistro()));

            if ($idrec != $idrecAnt) {
                $idrecAnt = $idrec;
                FPA::escreveArquivo($nomeArquivo, $idrec.RegistroDIRF::QUEBRA_LINHA_CR_LF);
            }

            FPA::escreveArquivo($nomeArquivo, $registro.RegistroDIRF::QUEBRA_LINHA_CR_LF);
        }
        
        foreach($this->_registroPSE as $registro) {
            FPA::escreveArquivo($nomeArquivo, $registro.RegistroDIRF::QUEBRA_LINHA_CR_LF);
        }

        FPA::escreveArquivo($nomeArquivo, $this->_fimDirf().RegistroDIRF::QUEBRA_LINHA_CR_LF);
        
        return $nomeArquivo;
    }

    private function _preparaRegistroDIRF(){

        if(is_null($this->_anoReferencia) || $this->_anoReferencia == ''){
            $this->msgErro .= "Está faltando o ano de referência.".Dirf::ql_msg;
        }

        if(is_null($this->_anoCalendario) || $this->_anoCalendario == ''){
            $this->msgErro .= "Está faltando o ano de calendário.".Dirf::ql_msg;
        }
        
        if($this->_idTipoDeclarac != 'S' && $this->_idTipoDeclarac != 'N' ){
            $this->msgErro .= "Está faltando a indicação do tipo de declaração.".Dirf::ql_msg;
        }

        $anoReferencia  = str_pad(substr($this->_anoReferencia,  0,  4),  4,' '); //Garante o tamanho do campo em 4
        $anoCalendario  = str_pad(substr($this->_anoCalendario,  0,  4),  4,' '); //Garante o tamanho do campo em 4
        $idTipoDeclarac = str_pad(substr($this->_idTipoDeclarac, 0,  1),  1,' '); //Garante o tamanho do campo em 1
        $auxNrRecibo    = $this->_nrRecibo == null ? '' : str_pad(substr($this->_nrRecibo, 0, 12), 12, '0', STR_PAD_LEFT);

        if($anoReferencia >= '2023'){
            $valorReferencia = $this->entityManager->getRepository(Repositories::FPA_VALORREFERENCIAM)->retornaValorReferencia(
                $this->_nrOrg, $this->_nrOrgPadrao, $this->_mesCompetencia->format(DateUtil::FORMATO_BRASILEIRO), RegistroDIRF::IDE_LEIAUTE_DIRF
            );
            if(count($valorReferencia) == 0){
                throw new \Exception('Não foi possível encontrar Estrutura do Layout para a competência atual.');
            }else{
                $ideEstrutLeiaute = $valorReferencia[0]->getDsobservacao();
            }
        } else {
            switch ($anoReferencia) {
                case '2014':
                    $ideEstrutLeiaute = 'F8UCL6S'; break;
                case '2015':
                    $ideEstrutLeiaute = 'M1LB5V2'; break;
                case '2016':
                    $ideEstrutLeiaute = 'L35QJS2'; break;
                case '2017':
                    $ideEstrutLeiaute = 'P49VS72'; break;
                case '2018':
                    $ideEstrutLeiaute = 'Q84FV63'; break;   
                case '2019':
                    $ideEstrutLeiaute = 'T17BS45'; break;
                case '2020':
                    $ideEstrutLeiaute = 'AT65HD8'; break;
                case '2021':
                    $ideEstrutLeiaute = 'VR4QLM8'; break;
                case '2022':
                    $ideEstrutLeiaute = 'XJFSFHB'; break;
                default:
                    $ideEstrutLeiaute = ''; break;
            }
        }
        
        $this->_registroDIRF->setAnoReferencia($anoReferencia);
        $this->_registroDIRF->setAnoCalendario($anoCalendario);
        $this->_registroDIRF->setIdTipoDeclarac($idTipoDeclarac);
        $this->_registroDIRF->setNrRecibo($auxNrRecibo);
        $this->_registroDIRF->setIdeLeiaute($ideEstrutLeiaute);

    }

    private function _preparaRegistroRESPO(){

        try{
            $params = array();
            $params['nrorg']            = $this->_nrOrg;
            $params['nrpessresponsa']   = $this->_nrPessResponsa;
            $params['dtcompetencia']    = $this->_dtCompetencia;
            $sqlResult = $this->queryDirf->get_respo($params);
        } catch(\Exception $e){
            throw new \Exception('Erro na query, campo RESPO, item 3.2.');
        }

        foreach($sqlResult as $val){
            if($val['NRCPF']      == '|'){
                //MsgCalculo::getInstance()->adicionaMensagem( "Responsável pela DIRF sem CPF.");
                $this->msgErro .= "Responsável pela DIRF sem CPF.".Dirf::ql_msg;
            }
            
            if($val['NMNOMERESP'] == '|'){
                //MsgCalculo::getInstance()->adicionaMensagem( "Responsável pela DIRF sem nome.");
                $this->msgErro .= "Responsável pela DIRF sem nome.".Dirf::ql_msg;
            }
            
            if($val['NRDDD']      == '|'){
                //MsgCalculo::getInstance()->adicionaMensagem( "Responsável pela DIRF sem Nº de DDD.");
                $this->msgErro .= "Responsável pela DIRF sem Nº de DDD.".Dirf::ql_msg;
            }
            
            if($val['NRTELEFONE'] == '|'){
                //MsgCalculo::getInstance()->adicionaMensagem( "Responsável pela DIRF sem Nº de telefone.");
                $this->msgErro .= "Responsável pela DIRF sem Nº de telefone.".Dirf::ql_msg;
            }

            $this->_registroRESPO->setCpf(str_replace('|','',$val['NRCPF']));
            $this->_registroRESPO->setNome(str_replace('|','',$val['NMNOMERESP']));
            $this->_registroRESPO->setDdd(str_replace('|','',$val['NRDDD']));
            $this->_registroRESPO->setTelefone(str_replace('|','',$val['NRTELEFONE']));
            $this->_registroRESPO->setRamal(str_replace('|','',$val['NRRAMAL']));
            $this->_registroRESPO->setFax(str_replace('|','',$val['NRFAX']));
            $this->_registroRESPO->setCorreioEletronico(str_replace('|','',$val['NMEMAIL']));
        }

    }

    private function _preparaRegistroDECPJ(){
        
        try{
            $params = array(
                "nrorg"            => $this->_nrOrg,
                "dtcompetencia"    => $this->_dtCompetencia,
                "nrestrresponsa"   => $this->_nrEstrResponsa,
                "idnaturezadecl"   => $this->_idNaturezaDecl,
                "idsocioostensi"   => $this->_idSocioOstensi,
                "iddepositjudic"   => $this->_idDepositJudic,
                "idinstitinvest"   => $this->_idInstitInvest,
                "idpagrendiexte"   => $this->_idPagRendiExte,
                "idpagplanosaud"   => $this->_idPagPlanoSaud,
                "idpagrelaccopa"   => $this->_idPagRelacCopa,
                "idpagrelacolimp"  => $this->_idPagRelacOlimp,
                "idpagsituaespe"   => $this->_idPagSituaEspe,
                "dteventoespeci"   => $this->_dtEventoEspeci,
            );
            $sqlResult = $this->queryDirf->get_decpj($params);
        } catch(\Exception $e){
            throw new \Exception('Erro na query, campo DECPJ, item 3.4.');
        }

        $registro = '';
        
        foreach($sqlResult as $val){
            if($val['CDCNPJ']          == '|')   //'IFs' para verificação de campos não preenchidos
                //MsgCalculo::getInstance()->adicionaMensagem( "Estrutura do responsável pela DIRF (nº ".$this->nrEstrResponsa.") sem CNPJ.");
                $this->msgErro .= "Estrutura do responsável pela DIRF (nº ".$this->nrEstrResponsa.") sem CNPJ.".Dirf::ql_msg;
            if($val['NOMEEMPRESARIAL'] == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Estrutura do responsável pela DIRF (nº ".$this->nrEstrResponsa.") sem razão social.");
                $this->msgErro .= "Estrutura do responsável pela DIRF (nº ".$this->nrEstrResponsa.") sem razão social.".Dirf::ql_msg;
            if($val['IDNATUREZADECLA'] == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Não há natureza do declarante (formulário, estrutura nº ".$this->nrEstrResponsa.").");
                $this->msgErro .= "Não há natureza do declarante (formulário, estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            if($val['CDCPFRESP']       == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Responsável perante o CNPJ não cadastrado ou sem CPF (estrutura nº ".$this->nrEstrResponsa.").");
                $this->msgErro .= "Responsável perante o CNPJ não cadastrado ou sem CPF (estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            if($val['IDSOCIOSTENS']    == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Falta indicador de sócio ostensivo (estrutura nº ".$this->nrEstrResponsa.").");
                $this->msgErro .= "Falta indicador de sócio ostensivo (estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            if($val['IDDEPOJUDIC']     == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Falta indicador de depósito de crédito decorrente de decisão judicial (estrutura nº ".$this->nrEstrResponsa.").");
                $this->msgErro .= "Falta indicador de depósito de crédito decorrente de decisão judicial (estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            if($val['IDINSTINVEST']    == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Falta indicador de declarante de instituição administradora (estrutura nº ".$this->nrEstrResponsa.").");
                $this->msgErro .= "Falta indicador de declarante de instituição administradora (estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            if($val['IDPAGRENDEXT']    == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Falta indicador de rendimentos pagos a residentes no exterior (estrutura nº ".$this->nrEstrResponsa.").");
                $this->msgErro .= "Falta indicador de rendimentos pagos a residentes no exterior (estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            if($val['IDPAGPLANSAUD']   == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Falta indicador de plano privado de assistência à saúde (estrutura nº ".$this->nrEstrResponsa.").");
                $this->msgErro .= "Falta indicador de plano privado de assistência à saúde (estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            if ($this->_anoReferencia >= 2016) {
                if($val['IDPAGRELCOPA']    == '|')
                    //MsgCalculo::getInstance()->adicionaMensagem( "Falta indicador de pagamentos relacionados à Copa das Confedêrações e do Mundo (estrutura nº ".$this->nrEstrResponsa.").");
                    $this->msgErro .= "Falta indicador de pagamentos relacionados à Copa das Confedêrações e do Mundo (estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            } else {
                unset($val['IDPAGRELCOPA']);
            }        
            if ($this->_anoReferencia >= 2016) {
                if ($val['IDPAGRELOLIMP'] == '|')
                    //MsgCalculo::getInstance()->adicionaMensagem( "Falta indicador de pagamentos relacionados aos Jogos Olímpicos e Paraolímpicos (estrutura nº " . $this->nrEstrResponsa . ")." . Dirf::ql_msg);
                    $this->msgErro .= "Falta indicador de pagamentos relacionados aos Jogos Olímpicos e Paraolímpicos (estrutura nº " . $this->nrEstrResponsa . ")." . Dirf::ql_msg;
            } else {
                unset($val['IDPAGRELOLIMP']);
            }
            if($val['IDPAGSITESPE']    == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Falta indicador de situação especial de declaração (estrutura nº ".$this->nrEstrResponsa.").");
                $this->msgErro .= "Falta indicador de situação especial de declaração (estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            if($val['IDPAGSITESPE'] == '|S' && $val['DTEVENTDECPJ'] == '|')
                //MsgCalculo::getInstance()->adicionaMensagem( "Falta data de situação especial de declaração (estrutura nº ".$this->nrEstrResponsa.").");
                $this->msgErro .= "Falta data de situação especial de declaração (estrutura nº ".$this->nrEstrResponsa.").".Dirf::ql_msg;
            
            /* Tipo de Regime de Apuração (Competência ou Caixa) */
            $this->_nrRegimeApur = $val['NRREGIMEAPUR'];

            $this->_registroDECPJ->setCnpj(str_replace('|','',$val['CDCNPJ']));
            $this->_registroDECPJ->setNmEmpresarial(str_replace('|','',$val['NOMEEMPRESARIAL']));
            $this->_registroDECPJ->setIdNaturezaDecl(str_replace('|','',$val['IDNATUREZADECLA']));
            $this->_registroDECPJ->setCpfResponsavel(str_replace('|','',$val['CDCPFRESP']));
            $this->_registroDECPJ->setIdSocioOstensi(str_replace('|','',$val['IDSOCIOSTENS']));
            $this->_registroDECPJ->setIdDepositJudic(str_replace('|','',$val['IDDEPOJUDIC']));
            $this->_registroDECPJ->setIdInstitInvest(str_replace('|','',$val['IDINSTINVEST']));
            $this->_registroDECPJ->setIdPagRendiExte(str_replace('|','',$val['IDPAGRENDEXT']));
            $this->_registroDECPJ->setIdPagPlanoSaud(str_replace('|','',$val['IDPAGPLANSAUD']));
            $this->_registroDECPJ->setIdPagEntidades(str_replace('|','',$val['IDPAGRELCOPA']));
            $this->_registroDECPJ->setIdFundaDirPriv(str_replace('|','',$val['IDPAGRELOLIMP']));
            $this->_registroDECPJ->setIdPagSituaEspe(str_replace('|','',$val['IDPAGSITESPE']));
            $this->_registroDECPJ->setDtEventoEspeci(str_replace('|','',$val['DTEVENTDECPJ']));
        }

    }

    private function _preparaRegistroPSE(){
        
        try{
            $params = array(
                "nrorg"             => $this->_nrOrg,
                "inicio"            => $this->_dsInicio,
                "fim"               => $this->_dsFim,
                "dtcompetencia_ini" => DateUtil::getDataDeString($this->_dtCompetencia,DateUtil::FORMATO_BRASILEIRO,true)->format($this->_nrOrg == 3260 ? 'd/05/Y' : 'd/01/Y'),
                "dtcompetencia"     => $this->_dtCompetencia,
                "nrgrupoinciden"    => $this->_nrGrupoInciden,
                "nrcenario"         => 1,
            );
            
            switch($this->_dsOrdem){ 
                case 'ALFABETICA':
                    $this->queryPart = "AND (VM.NMVINCULOM BETWEEN :inicio AND :fim)";
                    break;
                case 'DATA_ADMISSAO':
                    $this->queryPart = "AND (VM.DTADMISSAOVINC BETWEEN :inicio AND :fim)";
                    break;
                case 'MATRICULA':
                    $this->queryPart = "AND (VM.CDMATRICULA BETWEEN :inicio AND :fim)";
                    break;
                case 'ESTRUTURA':
                    if ($this->_dsFim) {
                        $this->queryPart = "AND (VH.NRESTRUTLEGAL = :inicio AND VH.NRESTRUTGEREN = :fim)";
                    } else {
                        $this->queryPart = "AND (VH.NRESTRUTLEGAL = :inicio AND VH.NRESTRUTGEREN  = NVL('', VH.NRESTRUTGEREN))";
                    }
                    break;
                case 'LISTA_VINCULO':
                    $inicio = is_array($this->_dsInicio) ? implode(',',$this->_dsInicio) : $this->_dsInicio;
                    $this->queryPart = "AND VM.NRVINCULOM IN ($inicio)";
                    break;
                case 'LISTA_ESTRUTURA':
                    $inicio = is_array($this->_dsInicio) ? implode(',',$this->_dsInicio) : $this->_dsInicio;
                    $this->queryPart = "AND VH.NRESTRUTLEGAL IN ($inicio)";
                    if($fim){
                        $fim = is_array($this->_dsFim) ? implode(',',$this->_dsFim) : $this->_dsFim;
                        $this->queryPart .= "AND VH.NRESTRUTGEREN IN ($fim)";
                    }
                    break; 
                case 'LOTE_VINCULO':
                    $inicio = $this->_dsInicio;
                    $this->queryPart .= "AND EXISTS (SELECT 1 
                                                     FROM FPA_ITEMLOTEVINC I
                                                    WHERE I.NRORG = VM.NRORG
                                                      AND I.NRVINCULOM = VM.NRVINCULOM
                                                      AND I.NRLOTEVINC = :inicio)";
                    break;
                default:
                    throw new \Exception( "Opção de ordenação inválida (".$this->_dsOrdem.").");
            }
        
            /*Ajusta a query para regime competência ou caixa*/
            // if($this->_nrRegimeApur == '2') {    //Regime Caixa
            //     $queryPartPse = "AND CF.DTOCORRENCIA BETWEEN ADD_MONTHS(TRUNC(TO_DATE( :dtcompetencia ), 'YEAR'), -1) AND ADD_MONTHS( :dtcompetencia, -1)";
            // } else {
                $queryPartPse = "AND CF.DTOCORRENCIA BETWEEN TRUNC( TO_DATE( :dtcompetencia ), 'YEAR' ) AND :dtcompetencia";
            // }
            
            if($this->_idApuraBeneficio == 'S'){
                $sqlResult = $this->queryDirf->get_pse_apurabeneficio($params,$this->queryPart,$queryPartPse);
            } else {
                $sqlResult = $this->queryDirf->get_pse($params,$this->queryPart,$queryPartPse);
            }
        } catch(\Exception $e){
            throw new \Exception('Erro na query, campo PSE, item 5. ('.$e->getMessage().')');
        }
        
        $pse = '';
        $opseAntes  = '';    //Armazena os valores anteriores
        $cnpjOpseAntes = '';
        $tpseAntes = '';      
        $cpfTitular = '';
        $this->_registroPSE = array();
        
        foreach($sqlResult as $val){
            
            if(isset($this->beneficiariosDirf[$val['NRCPFTITULAR']])) {
            //if(isset($this->registrosMagnetico[$val['NRCPFTITULAR']])) {
                
                if ($pse == '') {
                    $pse = $val['PSE'];
                    array_push($this->_registroPSE, $pse);    //Adiciona o registro PSE (somente uma vez)
                }
                
                $opse = $val['OPSE'] . $val['CNPJ_EMPR'] . $val['NOME_EMPR'] . $val['REG_ANS'];
                $cnpjOpse = $val['CNPJ_EMPR'];
                $tpse = $val['TPSE'] . $val['CDCPF'] . $val['NOME'] . $val['VALOR'];
                $tpseref = $val['TPSE'] . $val['CDCPF'] . $val['NOME'];
                $dtpse = $val['DTPSE'] . $val['CDCPFDEP'] . $val['DTNASCDEP'] . $val['NOMEDEP'] . $val['RELACDEP'] . $val['VALORDEP'];
                $isDep   = $val['NOMEDEP'] != '|';      //Flag para indicação que o TPSE / registro atual se trata de um dependente
                
//                if ($opse != $opseAntes) {              //Verifica se houve novo registro do tipo OPSE
                if ($cnpjOpse != $cnpjOpseAntes) {              //Verifica se houve novo registro do tipo OPSE
                    if ($val['CDCNPJESTRUT'] == '|')    //'IFs' para verificação de campos não preenchidos
                        $this->msgErro .= "Estrutura (" . $val['NMRAZSOCESTRUT'] . ") sem CNPJ." . Dirf::ql_msg;
//                    $opseAntes = $opse;                 //Atualiza o OPSE corrente
                    $cnpjOpseAntes = $cnpjOpse;         //Atualiza o OPSE corrente
                    $tpseAntes = '';                    //Força a utilização do TPSE já que o OPSE mudou
                    array_push($this->_registroPSE, $opse);//Adiciona o registro OPSE
                }
    
                if ($tpse != $tpseAntes && !$isDep) {       //Verifica se houve novo registro do tipo TPSE para TITULAR
                    $tpseAntes  = $tpse;                    //Atualiza o TPSE corrente
                    $cpfTitular = $val['NRCPFTITULAR'];     //Registra CPF do titular para identificação na parte de dependentes DTPSE
                    array_push($this->_registroPSE, $tpse);          //Adiciona o registro TPSE
                }
    
                if ($isDep && $cpfTitular == $val['NRCPFTITULAR']) {    //É dependente do titular corrente?
                    array_push($this->_registroPSE, $dtpse); 
                }

                if ($this->_idProcessaVinc == 'S') {
                    $dsRegistro = $val['NOMEDEP'] == '|' ? $opse . $tpseAntes: $opse . $tpseAntes . $dtpse;
                        
                    $this->_objMagnetico->setAllToPSEObj($val['NRCPFTITULAR'], $dsRegistro, str_replace('|', '', $val['NOME']));
                }
            }

        }
        
        if (!empty($this->_registroPSE)) { //Caso tenha gerado plano(s) de saúde altera o identificador do registro DECPJ
            $this->_registroDECPJ->setIdPagPlanoSaud('S');
        }

    }
    
    private function setRegistrosMagnetico(){
        $registros = $this->_objMagnetico->retornaRegistros();
        foreach ($registros as $registro) {
            
            //Se estiver marcado no formulário para somente vinculos com rendimento superior a X
            //Se estiver marcado no formulário para somente vinculos com retenção
            if (($this->_idVincRendimento == 'S' && $registro->getVrtotalrend() < $this->_vrMinRendimento) && ($this->_idVincRetencao == 'S' && $registro->getVrtotimpretido() == 0)) {
                continue;
            }
            
            $this->registrosMagnetico[] = $registro;
            $this->beneficiariosDirf[$registro->getNrcpfpessoa()] = 1;
        }
    }
    
    private function _fimDirf(){
        return 'FIMDIRF|';
    }
    
    public function geraRelatorio(){
        $filtro = array(
            'P_COMPETENCIA'=> $this->_dtCompetencia,
            'P_NRORG'      => $this->_nrOrg,
            'P_ANOREF'     => $this->_anoReferencia,
            'P_ANOCALEN'   => $this->_anoCalendario,
            'P_VINCULO'    => '', /*$vinculos_str,*/
            'P_ESTRUTURARESP' => $this->_nrEstrResponsa
        );
        return $filtro; 
    }
    
    public function geraRelatorioAnalitico() {
        $filtro = array(
            'P_COMPETENCIA'   => $this->_dtCompetencia,
            'P_NRORG'         => $this->_nrOrg,
            'P_VINCULO'       => '', /*$vinculos_str,*/
            'P_ESTRUTURARESP' => $this->_nrEstrResponsa
        );
        return $filtro;
        
    }

}